


04/16/93 E. Correia
WK#:581       MV#:3c
Breitkopf & Hărtel, Vol. 13
Clarinet Quintet
Trio II
Clarinet in A
1 0
Group memberships: sound, score
sound: part 1 of 5
score: part 1 of 5
$  K:0   Q:6   T:3/4   X:-11   C:4
C5     3        e     d  [     (&0p
E5     3        e     d  ]
measure 1
G5     3        e     d  [
E5     3        e     d  ]
C6     6        q     d        )
G5     3        e     d  [     (
E5     3        e     d  ]
measure 2
D5     3        e     d  [
F5     3        e     d  ]
A5     6        q     d        )
F5     3        e     d  [     (
D5     3        e     d  ]
measure 3
C5     3        e     d  [
B4     3        e     d  =
E5     3        e     d  =
D5     3        e     d  =
G5     3        e     d  =
F5     3        e     d  ]     )
measure 4
D#5    6        q #   d        (
E5     6        q     d        )
C5     3        e     d  [     (
E5     3        e     d  ]
measure 5
G5     3        e     d  [
E5     3        e     d  ]
C6     6        q     d        )
G5     3        e     d  [     (
E5     3        e     d  ]
measure 6
D5     3        e n   d  [     +
F5     3        e     d  ]
A5     6        q     d        )
rest   6        q
measure 7
rest  18
measure 8
rest   6        q
rest   6        q
D4     2        e  3  u  [     (*
A3     2        e  3  u  =
F3     2        e  3  u  ]      !
measure 9
A3     3        e     u  [     )
D4     3        e     u  =     .
F4     3        e     u  =     .
A4     3        e     u  =     .
D5     3        e     u  =     .
F5     3        e     u  ]     .
measure 10
A5     3        e     d  [     (
G5     3        e     d  =
F5     3        e     d  =
E5     3        e     d  =
F5     3        e     d  =
D5     3        e     d  ]     )
measure 11
C5    12        h     d        (
E5     3        e     d  [
D5     3        e     d  ]     )
measure 12
C5     6        q     d
rest   6        q
mheavy4         :||:
/END